@@ -40,7 +40,7 @@ impl Join {
 
     pub fn trigger(&self) {
         self.state.store(false, Ordering::Release);
-        if let Some(w) = self.to_wake.take(Ordering::Acquire) {
+        if let Some(w) = self.to_wake.take() {
             w.unpark();
         }
     }
@@ -49,11 +49,11 @@ impl Join {
         if self.state.load(Ordering::Acquire) {
             let cur = Blocker::current();
             // register the blocker first
-            self.to_wake.swap(cur.clone(), Ordering::Release);
+            self.to_wake.swap(cur.clone());
             // re-check the state
             if self.state.load(Ordering::Acquire) {
                 // successfully register the blocker
-            } else if let Some(w) = self.to_wake.take(Ordering::Acquire) {
+            } else if let Some(w) = self.to_wake.take() {
                 // it's already triggered
                 w.unpark();
             }
